AttError

Struct AttError 

pub struct AttError(/* private fields */);
Bluetooth Attribute Protocol error. See the Bluetooth Core Specification, Vol 3, Part F, 3.4.1.1

Implementations

Source

impl AttError

pub const SUCCESS: AttError

The operation completed successfully.

pub const INVALID_HANDLE: AttError

The attribute handle given was not valid on this server.

pub const READ_NOT_PERMITTED: AttError

The attribute cannot be read.

pub const WRITE_NOT_PERMITTED: AttError

The attribute cannot be written.

pub const INVALID_PDU: AttError

The attribute PDU was invalid.

pub const INSUFFICIENT_AUTHENTICATION: AttError

The attribute requires authentication before it can be read or written.

pub const REQUEST_NOT_SUPPORTED: AttError

Attribute server does not support the request received from the client.

pub const INVALID_OFFSET: AttError

Offset specified was past the end of the attribute.

pub const INSUFFICIENT_AUTHORIZATION: AttError

The attribute requires authorization before it can be read or written.

pub const PREPARE_QUEUE_FULL: AttError

Too many prepare writes have been queued.

pub const ATTRIBUTE_NOT_FOUND: AttError

No attribute found within the given attribute handle range.

pub const ATTRIBUTE_NOT_LONG: AttError

The attribute cannot be read or written using the Read Blob Request.

pub const INSUFFICIENT_ENCRYPTION_KEY_SIZE: AttError

The Encryption Key Size used for encrypting this link is insufficient.

pub const INVALID_ATTRIBUTE_VALUE_LENGTH: AttError

The attribute value length is invalid for the operation.

pub const UNLIKELY_ERROR: AttError

The attribute request that was requested has encountered an error that was unlikely, and therefore could not be completed as requested.

pub const INSUFFICIENT_ENCRYPTION: AttError

The attribute requires encryption before it can be read or written.

pub const UNSUPPORTED_GROUP_TYPE: AttError

The attribute type is not a supported grouping attribute as defined by a higher layer specification.

pub const INSUFFICIENT_RESOURCES: AttError

Insufficient Resources to complete the request.

pub const DATABASE_OUT_OF_SYNC: AttError

The server requests the client to rediscover the database.

pub const VALUE_NOT_ALLOWED: AttError

The attribute parameter value was not allowed.

pub const WRITE_REQUEST_REJECTED: AttError

Write Request Rejected

pub const CCCD_IMPROPERLY_CONFIGURED: AttError

Client Characteristic Configuration Descriptor Improperly Configured

pub const PROCEDURE_ALREADY_IN_PROGRESS: AttError

Procedure Already in Progress

pub const OUT_OF_RANGE: AttError

Out of Range

pub const fn from_u8(val: u8) -> Self

Converts a u8 value to an AttError.

pub const fn as_u8(self) -> u8

Converts an AttError to a u8 value.

pub fn is_application(&self) -> bool

Checks if the error code is in the application error range.

pub fn is_common_profile_or_service(&self) -> bool

Checks if the error code is in the common profile and service range.