Device

Struct Device 

pub struct Device { /* private fields */ }
A Bluetooth LE device.

Implementations

Source

impl Device

pub fn id(&self) -> DeviceId

Returns this device’s unique identifier.

pub fn name(&self) -> Result<String>

The local name for this device.

pub async fn name_async(&self) -> Result<String>

This method is kept for compatibility with bluest.

pub async fn is_connected(&self) -> bool

The connection status for this device.

NOTE: currently this just checks if it is registered in this library instance.

pub async fn is_paired(&self) -> Result<bool>

The pairing status for this device.

pub async fn pair(&self) -> Result<()>

Attempt to pair this device using the system default pairing UI.

pub async fn discover_services(&self) -> Result<Vec<Service>>

Discover the primary services of this device.

pub async fn discover_services_with_uuid( &self, uuid: Uuid, ) -> Result<Vec<Service>>

Discover the primary service(s) of this device with the given Uuid.

pub async fn services(&self) -> Result<Vec<Service>>

Get previously discovered services.

If no services have been discovered yet, this method will perform service discovery.

pub async fn service_changed_indications( &self, ) -> Result<impl Stream<Item = Result<ServicesChanged>> + Send + Unpin + '_>

(Experimental) Monitors the device for service changed indications.

This requires Android API level 31 or higher.

pub async fn rssi(&self) -> Result<i16>

Get the current signal strength from the device in dBm.

pub async fn open_l2cap_channel( &self, psm: u16, secure: bool, ) -> Result<L2capChannel>

Open an L2CAP connection-oriented channel (CoC) to this device.

This requires Android API level 29 or higher.