pub struct AttError(/* private fields */);Expand description
Bluetooth Attribute Protocol error. See the Bluetooth Core Specification, Vol 3, Part F, 3.4.1.1
Implementations
Sourceimpl AttError
impl AttError
Sourcepub const INVALID_HANDLE: AttError
pub const INVALID_HANDLE: AttError
The attribute handle given was not valid on this server.
Sourcepub const READ_NOT_PERMITTED: AttError
pub const READ_NOT_PERMITTED: AttError
The attribute cannot be read.
Sourcepub const WRITE_NOT_PERMITTED: AttError
pub const WRITE_NOT_PERMITTED: AttError
The attribute cannot be written.
Sourcepub const INVALID_PDU: AttError
pub const INVALID_PDU: AttError
The attribute PDU was invalid.
Sourcepub const INSUFFICIENT_AUTHENTICATION: AttError
pub const INSUFFICIENT_AUTHENTICATION: AttError
The attribute requires authentication before it can be read or written.
Sourcepub const REQUEST_NOT_SUPPORTED: AttError
pub const REQUEST_NOT_SUPPORTED: AttError
Attribute server does not support the request received from the client.
Sourcepub const INVALID_OFFSET: AttError
pub const INVALID_OFFSET: AttError
Offset specified was past the end of the attribute.
Sourcepub const INSUFFICIENT_AUTHORIZATION: AttError
pub const INSUFFICIENT_AUTHORIZATION: AttError
The attribute requires authorization before it can be read or written.
Sourcepub const PREPARE_QUEUE_FULL: AttError
pub const PREPARE_QUEUE_FULL: AttError
Too many prepare writes have been queued.
Sourcepub const ATTRIBUTE_NOT_FOUND: AttError
pub const ATTRIBUTE_NOT_FOUND: AttError
No attribute found within the given attribute handle range.
Sourcepub const ATTRIBUTE_NOT_LONG: AttError
pub const ATTRIBUTE_NOT_LONG: AttError
The attribute cannot be read or written using the Read Blob Request.
Sourcepub const INSUFFICIENT_ENCRYPTION_KEY_SIZE: AttError
pub const INSUFFICIENT_ENCRYPTION_KEY_SIZE: AttError
The Encryption Key Size used for encrypting this link is insufficient.
Sourcepub const INVALID_ATTRIBUTE_VALUE_LENGTH: AttError
pub const INVALID_ATTRIBUTE_VALUE_LENGTH: AttError
The attribute value length is invalid for the operation.
Sourcepub const UNLIKELY_ERROR: AttError
pub const UNLIKELY_ERROR: AttError
The attribute request that was requested has encountered an error that was unlikely, and therefore could not be completed as requested.
Sourcepub const INSUFFICIENT_ENCRYPTION: AttError
pub const INSUFFICIENT_ENCRYPTION: AttError
The attribute requires encryption before it can be read or written.
Sourcepub const UNSUPPORTED_GROUP_TYPE: AttError
pub const UNSUPPORTED_GROUP_TYPE: AttError
The attribute type is not a supported grouping attribute as defined by a higher layer specification.
Sourcepub const INSUFFICIENT_RESOURCES: AttError
pub const INSUFFICIENT_RESOURCES: AttError
Insufficient Resources to complete the request.
Sourcepub const DATABASE_OUT_OF_SYNC: AttError
pub const DATABASE_OUT_OF_SYNC: AttError
The server requests the client to rediscover the database.
Sourcepub const VALUE_NOT_ALLOWED: AttError
pub const VALUE_NOT_ALLOWED: AttError
The attribute parameter value was not allowed.
Sourcepub const WRITE_REQUEST_REJECTED: AttError
pub const WRITE_REQUEST_REJECTED: AttError
Write Request Rejected
Sourcepub const CCCD_IMPROPERLY_CONFIGURED: AttError
pub const CCCD_IMPROPERLY_CONFIGURED: AttError
Client Characteristic Configuration Descriptor Improperly Configured
Sourcepub const PROCEDURE_ALREADY_IN_PROGRESS: AttError
pub const PROCEDURE_ALREADY_IN_PROGRESS: AttError
Procedure Already in Progress
Sourcepub const OUT_OF_RANGE: AttError
pub const OUT_OF_RANGE: AttError
Out of Range
Sourcepub fn is_application(&self) -> bool
pub fn is_application(&self) -> bool
Checks if the error code is in the application error range.
Sourcepub fn is_common_profile_or_service(&self) -> bool
pub fn is_common_profile_or_service(&self) -> bool
Checks if the error code is in the common profile and service range.