CharacteristicProperties

Struct CharacteristicProperties 

#[non_exhaustive]
pub struct CharacteristicProperties { pub broadcast: bool, pub read: bool, pub write_without_response: bool, pub write: bool, pub notify: bool, pub indicate: bool, pub authenticated_signed_writes: bool, pub extended_properties: bool, pub reliable_write: bool, pub writable_auxiliaries: bool, }
GATT characteristic properties as defined in the Bluetooth Core Specification, Vol 3, Part G, 3.3.1.1.

Extended properties are also included as defined in 3.3.3.1.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
broadcast: boolread: boolwrite_without_response: boolwrite: boolnotify: boolindicate: boolauthenticated_signed_writes: boolextended_properties: boolreliable_write: boolwritable_auxiliaries: bool

Implementations

Source

impl CharacteristicProperties

pub fn from_bits(bits: u32) -> Self

Raw transmutation from u32.

Extended properties are in the upper bits.

pub fn to_bits(self) -> u32

Raw transmutation to u32.

Extended properties are in the upper bits.